Learn R Programming

hrr (version 1.1.1)

ncols: Computes the maximum width of terminal window.

Description

ncols detects the maximum number of columns of the current terminal window. Note that columns are normally the same as characters except in CJK languages.

Usage

ncols(set_option = TRUE)

Arguments

set_option
whether to automatically set the R terminal width to the system terminal maximum number of columns [default TRUE]

Value

The number of terminal window columns.